@@ -13,6 +13,7 @@ class Recipe(object):
     update = install
 
     def __setitem__(self, name, data):
+        data = dict(stringify(name, i) for i in data.items())
         self.buildout._raw[name] = data
         self.buildout[name]
 
@@ -20,5 +21,16 @@ class Recipe(object):
         parser = ConfigParser.RawConfigParser()
         parser.readfp(cStringIO.StringIO(textwrap.dedent(data)))
 
-        for section in parser.sections():
+        for section in sorted(parser.sections()):
             self[section] = dict(parser.items(section))
+
+validtypes = unicode, int
+
+def stringify(section, (key, value)):
+    if not isinstance(value, str):
+        if isinstance(value, validtypes):
+            value = str(value)
+        else:
+            raise TypeError("Invalid type: %s for %s:%s, %r" %
+                            (type(value), section, key, value))
+    return key, value
